
This page lists all ValueSets and CodeSystems defined as part of this specification. 

As well as these included definitions this specification typically references [National Clinical Terminology Service (NCTS)](https://www.healthterminologies.gov.au/integration/R4/fhir) terminology resources. 


<div class="stu-note">
Implementers are advised to take note that expansions of value sets visible in this guide may differ from expansions returned with a server using <a href="http://terminology.hl7.org/6.0.2">HL7 Terminology (THO)</a> version 6.0.0 or higher.
</div> 

### Value Sets

See the [FHIR terminology section]({{site.data.fhir.path}}terminologies-valuesets.html) for a complete discussion on value sets and a list of value set names used in FHIR.  Many value sets used in this guide are defined in the base FHIR specification. The following value sets are unique to this guide and not listed in the base FHIR specification.

|ValueSet|Profile where used|Published|
|---|---|---|
|[Accession Number Type](ValueSet-accession-number-type.html)|[AU Accession Number](StructureDefinition-au-accessionnumber.html)|AU Base|
|[ActEncounterCode - AU Extended](ValueSet-au-v3-ActEncounterCode-extended.html)|[AU Base Encounter](StructureDefinition-au-encounter.html)|AU Base|
|[Adverse Reaction Agent](https://healthterminologies.gov.au/fhir/ValueSet/adverse-reaction-agent-1)|[AU Base Allergy Intolerance](StructureDefinition-au-allergyintolerance.html)|NCTS|
|[AMT Medicinal Product and Substances](ValueSet-amt-mp-codes.html)|[AU Base Medication](StructureDefinition-au-medication.html)|AU Base|
|[Assertion Of Absence](https://healthterminologies.gov.au/fhir/ValueSet/assertion-of-absence-1)|[AU Assertion of No Relevant Finding](StructureDefinition-au-norelevantfinding.html)|NCTS|
|[AU Time Zone](ValueSet-au-timezone.html)|[Australian Time Zone](StructureDefinition-au-timezone.html)|AU Base|
|[Australian Immunisation Register Vaccine](https://healthterminologies.gov.au/fhir/ValueSet/australian-immunisation-register-vaccine-1)|[AU Base Immunisation](StructureDefinition-au-immunization.html)|NCTS|
|[Australian Indigenous Status](https://healthterminologies.gov.au/fhir/ValueSet/australian-indigenous-status-1)|[Australian Indigenous Status](StructureDefinition-indigenous-status.html)|NCTS|
|[Australian Medication](https://healthterminologies.gov.au/fhir/ValueSet/australian-medication-1)|[AU Base Medication](StructureDefinition-au-medication.html), [AU Base Medication Administration](StructureDefinition-au-medicationadministration.html), [AU Base Medication Dispense](StructureDefinition-au-medicationdispense.html), [AU Base Medication Request](StructureDefinition-au-medicationrequest.html), [AU Base Medication Statement](StructureDefinition-au-medicationstatement.html)|NCTS|
|[Australian Pronouns](https://healthterminologies.gov.au/fhir/ValueSet/australian-pronouns-1)|[Individual Pronouns](http://hl7.org/fhir/StructureDefinition/individual-pronouns)|NCTS|
|[Australian States and Territories](https://healthterminologies.gov.au/fhir/ValueSet/australian-states-territories-2)|[Australian Address](StructureDefinition-au-address.html)|NCTS|
|[Australian Veteran Status](https://healthterminologies.gov.au/fhir/ValueSet/australian-veteran-status-1)|[Australian Veteran Status](StructureDefinition-veteran-status.html)|NCTS|
|[Body Site](https://healthterminologies.gov.au/fhir/ValueSet/body-site-1)|[AU Base Body Structure](StructureDefinition-au-bodystructure.html), [AU Base Condition](StructureDefinition-au-condition.html), [AU Base Diagnostic Imaging Result](StructureDefinition-au-imagingresult.html), [AU Base Diagnostic Request](StructureDefinition-au-diagnosticrequest.html), [AU Base Dosage](StructureDefinition-au-dosage.html), [AU Base Medication Administration](StructureDefinition-au-medicationadministration.html), [AU Base Procedure](StructureDefinition-au-procedure.html), [AU Base Specimen](StructureDefinition-au-specimen.html)|NCTS|
|[Body Site Relative Site Qualifier](https://healthterminologies.gov.au/fhir/ValueSet/body-site-relative-site-qualifier-1)|[AU Base Body Structure](StructureDefinition-au-bodystructure.html)|NCTS|
|[Clinical Condition](https://healthterminologies.gov.au/fhir/ValueSet/clinical-condition-1)|[AU Base Condition](StructureDefinition-au-condition.html)|NCTS|
|[Clinical Finding](https://healthterminologies.gov.au/fhir/ValueSet/clinical-finding-1)|[AU Base Allergy Intolerance](StructureDefinition-au-allergyintolerance.html), [AU Base Condition](StructureDefinition-au-condition.html), [AU Base Diagnostic Imaging Report](StructureDefinition-au-imagingreport.html), [AU Base Diagnostic Report](StructureDefinition-au-diagnosticreport.html), [AU Base Dosage](StructureDefinition-au-dosage.html), [AU Base Pathology Report](StructureDefinition-au-pathologyreport.html)|NCTS|
|[Clinical Specialty](https://healthterminologies.gov.au/fhir/ValueSet/clinical-specialty-1)|[AU Base Healthcare Service](StructureDefinition-au-healthcareservice.html), [AU Base Practitioner Role](StructureDefinition-au-practitionerrole.html)|NCTS|
|[Jurisdiction ValueSet - AU Extended](ValueSet-au-jurisdiction-extended.html)|[Person Recorded Sex Or Gender](http://hl7.org/fhir/StructureDefinition/individual-recordedSexOrGender)|AU Base|
|[AU Recorded Sex or Gender (RSG) Source Document Type](ValueSet-rsg-source-document-type.html)|[Person Recorded Sex Or Gender](http://hl7.org/fhir/StructureDefinition/individual-recordedSexOrGender)|AU Base|
|[AU Recorded Sex or Gender Type](ValueSet-rsg-type.html)|[Person Recorded Sex Or Gender](http://hl7.org/fhir/StructureDefinition/individual-recordedSexOrGender)|AU Base|
|[Common Languages in Australia](https://healthterminologies.gov.au/fhir/ValueSet/common-languages-australia-2)|[AU Base Patient](StructureDefinition-au-patient.html), [AU Base Practitioner](StructureDefinition-au-practitioner.html), [AU Base Related Person](StructureDefinition-au-relatedperson.html)|NCTS|
|[Concurrent Supply Grounds](https://healthterminologies.gov.au/fhir/ValueSet/concurrent-supply-grounds-1)|[Subsidised Concurrent Supply](StructureDefinition-subsidised-concurrent-supply.html)|NCTS|
|[Contact Purpose](ValueSet-contact-purpose.html)|[AU Base Organisation](StructureDefinition-au-organization.html), [Contact Purpose](StructureDefinition-contact-purpose.html)|AU Base|
|[Contact Relationship Type](https://healthterminologies.gov.au/fhir/ValueSet/contact-relationship-type-3)|[AU Base Patient](StructureDefinition-au-patient.html)|NCTS|
|[Date Accuracy Indicator](https://healthterminologies.gov.au/fhir/ValueSet/date-accuracy-indicator-1)|[Date Accuracy Indicator](StructureDefinition-date-accuracy-indicator.html), [Date of Arrival](StructureDefinition-date-of-arrival.html)|NCTS|
|[DVA Entitlement](ValueSet-dva-entitlement.html)|[AU DVA Number](StructureDefinition-au-dvanumber.html)|AU Base|
|[Encounter Type](https://healthterminologies.gov.au/fhir/ValueSet/encounter-type-1)|[AU Base Encounter](StructureDefinition-au-encounter.html)|NCTS|
|[Evaluation Procedure](https://healthterminologies.gov.au/fhir/ValueSet/evaluation-procedure-1)|[AU Base Diagnostic Report](StructureDefinition-au-diagnosticreport.html), [AU Base Diagnostic Request](StructureDefinition-au-diagnosticrequest.html), [AU Base Diagnostic Result](StructureDefinition-au-diagnosticresult.html)|NCTS|
|[Gender Identity Response](https://healthterminologies.gov.au/fhir/ValueSet/gender-identity-response-1)|[Individual Gender Identity](http://hl7.org/fhir/StructureDefinition/individual-genderIdentity)|NCTS|
|[Health Program Participation Status](https://healthterminologies.gov.au/fhir/ValueSet/health-program-participation-status-1)|[AU Health Program Participation Summary](StructureDefinition-au-healthprogramparticipation.html)|NCTS|
|[Healthcare Organisation Role Type](https://healthterminologies.gov.au/fhir/ValueSet/healthcare-organisation-role-type-1)|[AU Base Organisation](StructureDefinition-au-organization.html)|NCTS|
|[hl7VS-degreeLicenseCertificate - AU Extended](ValueSet-au-v2-0360-extended.html)|[AU Base Practitioner](StructureDefinition-au-practitioner.html)|AU Base|
|[hl7VS-identifierType - AU Extended](ValueSet-au-v2-0203-extended.html)|[AU Australian Business Number](StructureDefinition-au-australianbusinessnumber.html), [AU Australian Company Number](StructureDefinition-au-australiancompanynumber.html), [AU Australian Registered Body Number](StructureDefinition-au-australianregistredbodynumber.html)|AU Base|
|[hl7VS-providerRole - AU Extended](ValueSet-au-v2-0443-extended.html)|[AU Base Immunisation](StructureDefinition-au-immunization.html)|AU Base|
|[Imaging Anatomic Region Of Interest](https://healthterminologies.gov.au/fhir/ValueSet/imaging-anatomic-region-of-interest-1)|[AU Base Diagnostic Imaging Report](StructureDefinition-au-imagingreport.html), [AU Base Diagnostic Imaging Result](StructureDefinition-au-imagingresult.html)|NCTS|
|[Imaging Procedure](https://healthterminologies.gov.au/fhir/ValueSet/imaging-procedure-1)|[AU Base Diagnostic Imaging Report](StructureDefinition-au-imagingreport.html), [AU Base Diagnostic Imaging Result](StructureDefinition-au-imagingresult.html)|NCTS|
|[Immunisation Anatomical Site](https://healthterminologies.gov.au/fhir/ValueSet/immunisation-anatomical-site-1)|[AU Base Immunisation](StructureDefinition-au-immunization.html)|NCTS|
|[Immunisation Route of Administration](https://healthterminologies.gov.au/fhir/ValueSet/immunisation-route-of-administration-1)|[AU Base Immunisation](StructureDefinition-au-immunization.html)|NCTS|
|[Indicator of Hypersensitivity or Intolerance to Substance](https://healthterminologies.gov.au/fhir/ValueSet/indicator-hypersensitivity-intolerance-to-substance-2)|[AU Base Allergy Intolerance](StructureDefinition-au-allergyintolerance.html)|NCTS|
|[Individual Healthcare Identifier Record Status](https://healthterminologies.gov.au/fhir/ValueSet/ihi-record-status-1)|[IHI Record Status](StructureDefinition-ihi-record-status.html)|NCTS|
|[Individual Healthcare Identifier Status](https://healthterminologies.gov.au/fhir/ValueSet/ihi-status-1)|[IHI Record Status](StructureDefinition-ihi-record-status.html)|NCTS|
|[Location Type (Physical) - AU Extended](ValueSet-au-location-physical-type-extended.html)|[AU Base Location](StructureDefinition-au-location.html)|AU Base|
|[Medication Form](https://healthterminologies.gov.au/fhir/ValueSet/medication-form-1)|[AU Base Medication](StructureDefinition-au-medication.html)|NCTS|
|[Medication Reason Taken](https://healthterminologies.gov.au/fhir/ValueSet/medication-reason-taken-1)|[AU Base Medication Statement](StructureDefinition-au-medicationstatement.html)|NCTS|
|[Medication Type](ValueSet-medication-type.html)|[Medication Type](StructureDefinition-medication-type.html)|AU Base|
|[Medicine Item Change](ValueSet-medicine-item-change.html)|[AU Medicine List](StructureDefinition-au-medlist.html)|AU Base|
|[Medicine Substitution Reason](https://healthterminologies.gov.au/fhir/ValueSet/medicine-substitution-reason-1)|[AU Base Medication Dispense](StructureDefinition-au-medicationdispense.html), [AU Base Medication Request](StructureDefinition-au-medicationrequest.html)|NCTS|
|[MIMS](ValueSet-mims.html)|[AU Base Medication](StructureDefinition-au-medication.html), [AU Base Medication Administration](StructureDefinition-au-medicationadministration.html), [AU Base Medication Dispense](StructureDefinition-au-medicationdispense.html), [AU Base Medication Request](StructureDefinition-au-medicationrequest.html), [AU Base Medication Statement](StructureDefinition-au-medicationstatement.html)|AU Base|
|[Name Context](ValueSet-name-context.html)|[Name Context](StructureDefinition-name-context.html)|AU Base|
|[Observation Category Codes - AU Extended](ValueSet-au-observation-category-extended.html)||AU Base|
|[Order Identifier Type](ValueSet-order-identifier-type.html)|[AU Local Order Identifier](StructureDefinition-au-localorderidentifier.html)|AU Base|
|[Participation in Health Program](https://healthterminologies.gov.au/fhir/ValueSet/participation-in-health-program-1)|[AU Health Program Participation Summary](StructureDefinition-au-healthprogramparticipation.html)|NCTS|
|[Pathology Diagnostic Service Category](https://healthterminologies.gov.au/fhir/ValueSet/pathology-diagnostic-service-category-1)|[AU Base Pathology Report](StructureDefinition-au-pathologyreport.html), [AU Base Pathology Result](StructureDefinition-au-pathologyresult.html)|NCTS|
|[PBS Item Codes](ValueSet-pbs-item.html)|[AU Base Medication](StructureDefinition-au-medication.html), [AU Base Medication Administration](StructureDefinition-au-medicationadministration.html), [AU Base Medication Dispense](StructureDefinition-au-medicationdispense.html), [AU Base Medication Request](StructureDefinition-au-medicationrequest.html), [AU Base Medication Statement](StructureDefinition-au-medicationstatement.html)|AU Base|
|[Procedure](https://healthterminologies.gov.au/fhir/ValueSet/procedure-1)|[AU Base Procedure](StructureDefinition-au-procedure.html)|NCTS|
|[RCPA - SPIA Chemical Pathology Terminology Reference Set](https://www.healthterminologies.gov.au/integration/R4/fhir/ValueSet/spia-chemical-pathology-refset-3)|[AU Base Pathology Report](StructureDefinition-au-pathologyreport.html), [AU Base Pathology Result](StructureDefinition-au-pathologyresult.html)|NCTS|
|[RCPA - SPIA Haematology Terminology Reference Set](https://www.healthterminologies.gov.au/integration/R4/fhir/ValueSet/spia-haematology-refset-3)|[AU Base Pathology Report](StructureDefinition-au-pathologyreport.html), [AU Base Pathology Result](StructureDefinition-au-pathologyresult.html)|NCTS|
|[RCPA - SPIA Immunopathology Terminology Reference Set](https://www.healthterminologies.gov.au/integration/R4/fhir/ValueSet/spia-immunopathology-refset-3)|[AU Base Pathology Report](StructureDefinition-au-pathologyreport.html), [AU Base Pathology Result](StructureDefinition-au-pathologyresult.html)|NCTS|
|[RCPA - SPIA Microbiology Serology Molecular Pathology Terminology Reference Set](https://www.healthterminologies.gov.au/integration/R4/fhir/ValueSet/spia-microbiology-serology-molecular-refset-3)|[AU Base Pathology Report](StructureDefinition-au-pathologyreport.html), [AU Base Pathology Result](StructureDefinition-au-pathologyresult.html)|NCTS|
|[RCPA SPIA Pathology Reporting](https://healthterminologies.gov.au/fhir/ValueSet/spia-pathology-reporting-1)|[AU Base Pathology Report](StructureDefinition-au-pathologyreport.html), [AU Base Pathology Result](StructureDefinition-au-pathologyresult.html)|NCTS|
|[Reason For Non Participation In Health Program](https://healthterminologies.gov.au/fhir/ValueSet/reason-non-participation-health-program-1)|[AU Health Program Participation Summary](StructureDefinition-au-healthprogramparticipation.html)|NCTS|
|[Reason for Request](https://healthterminologies.gov.au/fhir/ValueSet/reason-for-request-1)|[AU Base Diagnostic Request](StructureDefinition-au-diagnosticrequest.html), [AU Base Medication Request](StructureDefinition-au-medicationrequest.html)|NCTS|
|[Reason Vaccine Administered](https://healthterminologies.gov.au/fhir/ValueSet/reason-vaccine-administered-1)|[AU Base Immunisation](StructureDefinition-au-immunization.html)|NCTS|
|[Reason Vaccine Not Administered](https://healthterminologies.gov.au/fhir/ValueSet/reason-vaccine-not-administered-3)|[AU Base Immunisation](StructureDefinition-au-immunization.html)|NCTS|
|[Related Person Relationship Type](https://healthterminologies.gov.au/fhir/ValueSet/related-person-relationship-type-1)|[AU Base Related Person](StructureDefinition-au-relatedperson.html)|NCTS|
|[Route of Administration](https://healthterminologies.gov.au/fhir/ValueSet/route-of-administration-1)|[AU Base Allergy Intolerance](StructureDefinition-au-allergyintolerance.html), [AU Base Dosage](StructureDefinition-au-dosage.html), [AU Base Medication Administration](StructureDefinition-au-medicationadministration.html)|NCTS|
|[Separation Mode](https://healthterminologies.gov.au/fhir/ValueSet/separation-mode-1)|[AU Base Encounter](StructureDefinition-au-encounter.html)|NCTS|
|[Service Provision Conditions Australian Concepts](ValueSet-service-provision-conditions.html)|[AU Base Healthcare Service](StructureDefinition-au-healthcareservice.html)|NCTS|
|[Service Type](https://healthterminologies.gov.au/fhir/ValueSet/service-type-1)|[AU Base Encounter](StructureDefinition-au-encounter.html), [AU Base Healthcare Service](StructureDefinition-au-healthcareservice.html)|NCTS|
|[ServiceDeliveryLocationRoleType - AU Extended](ValueSet-au-v3-ServiceDeliveryLocationRoleType-extended.html)|[AU Base Location](StructureDefinition-au-location.html)|AU Base|
|[Specimen Collection Procedure](https://healthterminologies.gov.au/fhir/ValueSet/specimen-collection-procedure-1)|[AU Base Specimen](StructureDefinition-au-specimen.html)|NCTS|
|[Specimen Container Type](https://healthterminologies.gov.au/fhir/ValueSet/specimen-container-type-1)|[AU Base Specimen](StructureDefinition-au-specimen.html)|NCTS|
|[Specimen Type](https://healthterminologies.gov.au/fhir/ValueSet/specimen-type-1)|[AU Base Specimen](StructureDefinition-au-specimen.html)|NCTS|
|[Substance](https://healthterminologies.gov.au/fhir/ValueSet/substance-1)|[AU Base Substance](StructureDefinition-au-substance.html)|NCTS|
|[Vaccination Target Disease](https://healthterminologies.gov.au/fhir/ValueSet/vaccination-target-disease-1)|[AU Base Immunisation](StructureDefinition-au-immunization.html)|NCTS|
{:.grid}


### Code Systems

See the [FHIR terminology section]({{site.data.fhir.path}}terminologies-systems.html) for a complete discussion on code systems and a list of codes system names used in FHIR.  Most code systems used in this guide are defined in the base FHIR specification. The following code systems are used in the above value sets.

|CodeSystem|ValueSet where used|Published|
|---|---|---|
|[ActCode](http://terminology.hl7.org/CodeSystem/v3-ActCode)|[ActEncounterCode - AU Extended](ValueSet-au-v3-ActEncounterCode-extended.html)|FHIR|
|[ActCode AU](CodeSystem-au-v3-ActCode.html)|[ActEncounterCode - AU Extended](ValueSet-au-v3-ActEncounterCode-extended.html)|AU Base|
|[AU Recorded Sex or Gender Source Document Type](CodeSystem-rsg-source-document-type.html)|[AU Recorded Sex or Gender (RSG) Source Document Type](ValueSet-rsg-source-document-type.html)|AU Base|
|[AU Recorded Sex or Gender Type](CodeSystem-rsg-type.html)|[AU Recorded Sex or Gender Type](ValueSet-rsg-type.html)|AU Base|
|[Australian and New Zealand Standard Industrial Classification (ANZSIC), 2006 (Revision 2.0)](https://www.healthterminologies.gov.au/integration/R4/fhir/CodeSystem/anzsic-2006-20130626)|[Australian And New Zealand Standard Industrial Classification](https://healthterminologies.gov.au/fhir/ValueSet/anzsic-1)|NCTS|
|[Australian Immunisation Register Vaccine](https://www.healthterminologies.gov.au/integration/R4/fhir/CodeSystem/australian-immunisation-register-vaccine-20221118)|[Australian Immunisation Register Vaccine](https://healthterminologies.gov.au/fhir/ValueSet/australian-immunisation-register-vaccine-1)|NCTS|
|[Australian Indigenous Status](https://healthterminologies.gov.au/fhir/CodeSystem/australian-indigenous-status-1)|[Australian Indigenous Status](https://healthterminologies.gov.au/fhir/ValueSet/australian-indigenous-status-1)|NCTS|
|[Australian States and Territories](https://healthterminologies.gov.au/fhir/CodeSystem/australian-states-territories-1)|[Australian States and Territories](https://healthterminologies.gov.au/fhir/ValueSet/australian-states-territories-2)|NCTS|
|[Australian Veteran Status](https://www.healthterminologies.gov.au/integration/R4/fhir/CodeSystem/australian-veteran-status-1)|[Australian Veteran Status](https://healthterminologies.gov.au/fhir/ValueSet/australian-veteran-status-1)|NCTS|
|[Concurrent Supply Grounds](https://healthterminologies.gov.au/fhir/CodeSystem/concurrent-supply-grounds-1)|[Concurrent Supply Grounds](https://healthterminologies.gov.au/fhir/ValueSet/concurrent-supply-grounds-1)|NCTS|
|[Contact Purpose](CodeSystem-contact-purpose.html)|[Contact Purpose](ValueSet-contact-purpose.html)|AU Base|
|[Data Absent Reason](https://www.healthterminologies.gov.au/integration/R4/fhir/CodeSystem/data-absent-reason)|[Australian Pronouns](https://healthterminologies.gov.au/fhir/ValueSet/australian-pronouns-1)|NCTS|
|[Date Accuracy Indicator](https://healthterminologies.gov.au/fhir/CodeSystem/date-accuracy-indicator-1)|[Date Accuracy Indicator](https://healthterminologies.gov.au/fhir/ValueSet/date-accuracy-indicator-1)|NCTS|
|[DegreeLicenseCertificate AU](CodeSystem-au-v2-0360.html)|[hl7VS-degreeLicenseCertificate - AU Extended](ValueSet-au-v2-0360-extended.html)|AU Base|
|[DiagnosticServiceSectionId](http://terminology.hl7.org/CodeSystem/v2-0074)|[Pathology Diagnostic Service Category](https://healthterminologies.gov.au/fhir/ValueSet/pathology-diagnostic-service-category-1)|FHIR|
|[IdentifierType](http://terminology.hl7.org/CodeSystem/v2-0203)|[Accession Number Type](ValueSet-accession-number-type.html), [Order Identifier Type](ValueSet-order-identifier-type.html), [hl7VS-identifierType - AU Extended](ValueSet-au-v2-0203-extended.html)|FHIR|
|[IdentifierType AU](CodeSystem-au-v2-0203.html)|[hl7VS-identifierType - AU Extended](ValueSet-au-v2-0203-extended.html), [DVA Entitlement](ValueSet-dva-entitlement.html)|AU Base|
|[Individual Healthcare Identifier Record Status](https://healthterminologies.gov.au/fhir/CodeSystem/ihi-record-status-1)|[Individual Healthcare Identifier Record Status](https://healthterminologies.gov.au/fhir/ValueSet/ihi-record-status-1)|NCTS|
|[Individual Healthcare Identifier Status](https://healthterminologies.gov.au/fhir/CodeSystem/ihi-status-1)|[Individual Healthcare Identifier Status](https://healthterminologies.gov.au/fhir/ValueSet/ihi-status-1)|NCTS|
|[ISO3166Part1](https://terminology.hl7.org/CodeSystem-ISO3166Part1.html)|[Jurisdiction ValueSet - AU Extended](ValueSet-au-jurisdiction-extended.html)|FHIR|
|[ISO3166_2](https://terminology.hl7.org/6.0.0/CodeSystem-v3-iso3166-2.html)|[Jurisdiction ValueSet - AU Extended](ValueSet-au-jurisdiction-extended.html)|FHIR|
|[LocationType](http://terminology.hl7.org/ValueSet/location-physical-type)|[Location Type (Physical) - AU Extended](ValueSet-au-location-physical-type-extended.html)|FHIR|
|[Location Type (Physical) AU](CodeSystem-au-location-physical-type.html)|[Location Type (Physical) - AU Extended](ValueSet-au-location-physical-type-extended.html)|AU Base|
|[Location Type AU](CodeSystem-au-location-type.html)|[ServiceDeliveryLocationRoleType - AU Extended](ValueSet-au-location-physical-type-extended.html)|AU Base|
|[LOINC](https://www.healthterminologies.gov.au/integration/R4/fhir/CodeSystem/LOINC-2.77)|[AU Recorded Sex or Gender (RSG) Source Document Type](ValueSet-rsg-source-document-type.html), [AU Recorded Sex or Gender Type](ValueSet-rsg-type.html), [RCPA - SPIA Chemical Pathology Terminology Reference Set](https://www.healthterminologies.gov.au/integration/R4/fhir/ValueSet/spia-chemical-pathology-refset-3), [RCPA - SPIA Haematology Terminology Reference Set](https://www.healthterminologies.gov.au/integration/R4/fhir/ValueSet/spia-haematology-refset-3), [RCPA - SPIA Immunopathology Terminology Reference Set](https://www.healthterminologies.gov.au/integration/R4/fhir/ValueSet/spia-immunopathology-refset-3), [RCPA - SPIA Microbiology Serology Molecular Pathology Terminology Reference Set](https://www.healthterminologies.gov.au/integration/R4/fhir/ValueSet/spia-microbiology-serology-molecular-refset-3), [RCPA SPIA Pathology Reporting](https://healthterminologies.gov.au/fhir/ValueSet/spia-pathology-reporting-1)|NCTS, FHIR|
|[Medication Type](CodeSystem-medication-type.html)|[Medication Type](ValueSet-medication-type.html)|AU Base|
|[Medicine Item Change](CodeSystem-medicine-item-change.html)|[Medicine Item Change](ValueSet-medicine-item-change.html)|AU Base|
|[Monthly Index of Medical Specialties (MIMS)](CodeSystem-mims-external.html)|[MIMS](ValueSet-mims.html)|AU Base|
|[Name Context](CodeSystem-name-context.html)|[Name Context](ValueSet-name-context.html)|AU Base|
|[Observation Category Codes AU](CodeSystem-au-observation-category.html)|[Observation Category Codes - AU Extended](ValueSet-au-observation-category-extended.html)|AU Base|
|[PBS Item Codes](CodeSystem-pbs-item-external.html)|[PBS Item Codes](ValueSet-pbs-item.html)|AU Base|
|[providerRole](http://terminology.hl7.org/CodeSystem/v2-0443)|[hl7VS-providerRole - AU Extended](ValueSet-au-v2-0443-extended.html)|FHIR|
|[providerRole AU](CodeSystem-au-v2-0443.html)|[hl7VS-providerRole - AU Extended](ValueSet-au-v2-0443-extended.html)|AU Base|
|[RoleCode](http://terminology.hl7.org/CodeSystem/v3-RoleCode)|[ServiceDeliveryLocationRoleType - AU Extended](ValueSet-au-v3-ServiceDeliveryLocationRoleType-extended.html)|FHIR|
|[Separation Mode](https://healthterminologies.gov.au/fhir/CodeSystem/separation-mode-1)|[Separation Mode](https://healthterminologies.gov.au/fhir/ValueSet/separation-mode-1)|NCTS|
|[Service Provision Conditions Australian Concepts](CodeSystem-service-provision-conditions.html)|[Service Provision Conditions Australian Concepts](ValueSet-service-provision-conditions.html)|AU Base|
|[SNOMED Clinical Terms (Australian extension)](https://www.healthterminologies.gov.au/integration/R4/fhir/CodeSystem/32506021000036107-20240630)|[Adverse Reaction Agent](https://healthterminologies.gov.au/fhir/ValueSet/adverse-reaction-agent-1), [AMT Medicinal Product and Substances](ValueSet-amt-mp-codes.html), [Assertion Of Absence](https://healthterminologies.gov.au/fhir/ValueSet/assertion-of-absence-1), [Australian Medication](https://healthterminologies.gov.au/fhir/ValueSet/australian-medication-1), [Body Site](https://healthterminologies.gov.au/fhir/ValueSet/body-site-1), [Body Site Relative Site Qualifier](https://healthterminologies.gov.au/fhir/ValueSet/body-site-relative-site-qualifier-1), [Clinical Condition](https://healthterminologies.gov.au/fhir/ValueSet/clinical-condition-1), [Clinical Finding](https://healthterminologies.gov.au/fhir/ValueSet/clinical-finding-1), [Clinical Specialty](https://healthterminologies.gov.au/fhir/ValueSet/clinical-specialty-1), [Contact Relationship Type](https://healthterminologies.gov.au/fhir/ValueSet/contact-relationship-type-3), [Encounter Type](https://healthterminologies.gov.au/fhir/ValueSet/encounter-type-1), [Evaluation Procedure](https://healthterminologies.gov.au/fhir/ValueSet/evaluation-procedure-1), [Gender Identity Response](https://healthterminologies.gov.au/fhir/ValueSet/gender-identity-response-1), [Health Program Participation Status](https://healthterminologies.gov.au/fhir/ValueSet/health-program-participation-status-1), [Healthcare Organisation Role Type](https://healthterminologies.gov.au/fhir/ValueSet/healthcare-organisation-role-type-1), [Imagine Procedure](https://healthterminologies.gov.au/fhir/ValueSet/imaging-procedure-1), [Imaging Anatomic Region Of Interest](https://healthterminologies.gov.au/fhir/ValueSet/imaging-anatomic-region-of-interest-1), [Immunisation Anatomical Site](https://healthterminologies.gov.au/fhir/ValueSet/immunisation-anatomical-site-1), [Immunisation Route of Administration](https://healthterminologies.gov.au/fhir/ValueSet/immunisation-route-of-administration-1), [Indicator of Hypersensitivity or Intolerance to Substance](https://healthterminologies.gov.au/fhir/ValueSet/indicator-hypersensitivity-intolerance-to-substance-2), [Medication Form](https://healthterminologies.gov.au/fhir/ValueSet/medication-form-1), [Medication Reason Taken](https://healthterminologies.gov.au/fhir/ValueSet/medication-reason-taken-1), [Medicine Substitution Reason](https://healthterminologies.gov.au/fhir/ValueSet/medicine-substitution-reason-1), [Participation in Health Program](https://healthterminologies.gov.au/fhir/ValueSet/participation-in-health-program-1), [Procedure](https://healthterminologies.gov.au/fhir/ValueSet/procedure-1), [Reason for Non Participation in Health Program](https://healthterminologies.gov.au/fhir/ValueSet/reason-non-participation-health-program-1), [Reason for Request](https://healthterminologies.gov.au/fhir/ValueSet/reason-for-request-1), [Reason Vaccine Administered](https://healthterminologies.gov.au/fhir/ValueSet/reason-vaccine-administered-1), [Reason Vaccine Not Administered](https://healthterminologies.gov.au/fhir/ValueSet/reason-vaccine-not-administered-3), [Related Person Relationship Type](https://healthterminologies.gov.au/fhir/ValueSet/related-person-relationship-type-1), [Service Type](https://healthterminologies.gov.au/fhir/ValueSet/service-type-1), [Specimen Collection Procedure](https://healthterminologies.gov.au/fhir/ValueSet/specimen-collection-procedure-1), [Specimen Container Type](https://healthterminologies.gov.au/fhir/ValueSet/specimen-container-type-1), [Specimen Type](https://healthterminologies.gov.au/fhir/ValueSet/specimen-type-1), [Substance](https://healthterminologies.gov.au/fhir/ValueSet/substance-1), [Vaccination Target Disease](https://healthterminologies.gov.au/fhir/ValueSet/vaccination-target-disease-1)|NCTS, FHIR|
|[Time Zones](https://www.iana.org/time-zones)|[AU Time Zone](ValueSet-au-timezone.html)|FHIR|
{:.grid}


### Concept Maps

See the [FHIR terminology section]({{site.data.fhir.path}}terminologies-conceptmaps.html) for a complete discussion on concept maps and a list of concept map names used in FHIR.  Most concept maps relevant to this guide are defined in the base FHIR specification. The following concept maps are unique to this guide and not listed in the base FHIR specification.

**Concept maps published in the NCTS**
- [Australian States and Territories v1 to Australian States and Territories v2](https://healthterminologies.gov.au/fhir/ConceptMap/australian-states-territories-v1-to-v2-1)
- [METeOR Indigenous Status 291036 to Australian Indigenous Status](https://healthterminologies.gov.au/fhir/ConceptMap/meteor-indigenous-291036-to-australian-indigenous-status-2)
- [METeOR Person Gender 635994 to HL7 FHIR AdministrativeGender](https://healthterminologies.gov.au/fhir/ConceptMap/meteor-person-gender-635994-to-hl7-fhir-administrativegender-1)
- [METeOR Person Gender 741825 to HL7 FHIR AdministrativeGender](https://healthterminologies.gov.au/fhir/ConceptMap/meteor-person-gender-741825-to-fhir-administrativegender-1)
- [METeOR Person Sex 635126 to Biological Sex](https://healthterminologies.gov.au/fhir/ConceptMap/meteor-person-sex-635126-to-biological-sex-1)
- [Reason Vaccine Not Administered v1 to Reason Vaccine Not Administered v2](https://healthterminologies.gov.au/fhir/ConceptMap/reason-vaccine-not-administered-v1-to-v2-1)
- [Reason Vaccine Not Administered v2 to Reason Vaccine Not Administered v3](https://healthterminologies.gov.au/fhir/ConceptMap/reason-vaccine-not-administered-v2-to-v3-1)
